@@ -4,7 +4,16 @@ from flet.animated_switcher import AnimatedSwitcher
 from flet.app_bar import AppBar
 from flet.audio import Audio
 from flet.banner import Banner
-from flet.buttons import ButtonStyle, OutlinedBorder
+from flet.bottom_sheet import BottomSheet
+from flet.buttons import (
+    BeveledRectangleBorder,
+    ButtonStyle,
+    CircleBorder,
+    CountinuosRectangleBorder,
+    OutlinedBorder,
+    RoundedRectangleBorder,
+    StadiumBorder,
+)
 from flet.card import Card
 from flet.checkbox import Checkbox
 from flet.circle_avatar import CircleAvatar
@@ -25,6 +34,7 @@ from flet.file_picker import (
 from flet.filled_button import FilledButton
 from flet.filled_tonal_button import FilledTonalButton
 from flet.flet import *
+from flet.flet_app import FletApp
 from flet.floating_action_button import FloatingActionButton
 from flet.gesture_detector import (
     DragEndEvent,
@@ -35,19 +45,29 @@ from flet.gesture_detector import (
     LongPressEndEvent,
     LongPressStartEvent,
     MouseCursor,
+    MultiTapEvent,
     ScaleEndEvent,
     ScaleStartEvent,
     ScaleUpdateEvent,
+    ScrollEvent,
     TapEvent,
 )
 from flet.gradients import LinearGradient, RadialGradient, SweepGradient
 from flet.grid_view import GridView
+from flet.haptic_feedback import HapticFeedback
 from flet.icon import Icon
 from flet.icon_button import IconButton
+from flet import icons
+from flet import colors
 from flet.image import Image
 from flet.list_tile import ListTile
 from flet.list_view import ListView
 from flet.markdown import Markdown
+from flet.navigation_bar import (
+    NavigationBar,
+    NavigationBarLabelBehavior,
+    NavigationDestination,
+)
 from flet.navigation_rail import NavigationRail, NavigationRailDestination
 from flet.outlined_button import OutlinedButton
 from flet.page import KeyboardEvent, LoginEvent, Page, RouteChangeEvent, ViewPopEvent
@@ -59,9 +79,11 @@ from flet.querystring import QueryString
 from flet.radio import Radio
 from flet.radio_group import RadioGroup
 from flet.ref import Ref
+from flet.responsive_row import ResponsiveRow
 from flet.row import Row
 from flet.semantics import Semantics
 from flet.shader_mask import ShaderMask
+from flet.shake_detector import ShakeDetector
 from flet.slider import Slider
 from flet.snack_bar import SnackBar
 from flet.stack import Stack
@@ -73,6 +95,8 @@ from flet.text_button import TextButton
 from flet.text_style import TextStyle
 from flet.textfield import TextField
 from flet.theme import PageTransitionsTheme, Theme
+from flet.tooltip import Tooltip
+from flet.transparent_pointer import TransparentPointer
 from flet.user_control import UserControl
 from flet.vertical_divider import VerticalDivider
 from flet.view import View
