@@ -11,6 +11,7 @@ from flet.types import (
     BorderRadiusValue,
     OffsetValue,
     PaddingValue,
+    ResponsiveNumber,
     RotateValue,
     ScaleValue,
 )
@@ -27,10 +28,12 @@ class FormFieldControl(ConstrainedControl):
         right: OptionalNumber = None,
         bottom: OptionalNumber = None,
         expand: Union[None, bool, int] = None,
+        col: Optional[ResponsiveNumber] = None,
         opacity: OptionalNumber = None,
         rotate: RotateValue = None,
         scale: ScaleValue = None,
         offset: OffsetValue = None,
+        aspect_ratio: OptionalNumber = None,
         animate_opacity: AnimationValue = None,
         animate_size: AnimationValue = None,
         animate_position: AnimationValue = None,
@@ -46,6 +49,7 @@ class FormFieldControl(ConstrainedControl):
         # FormField specific
         #
         text_size: OptionalNumber = None,
+        text_style: Optional[TextStyle] = None,
         label: Optional[str] = None,
         label_style: Optional[TextStyle] = None,
         icon: Optional[str] = None,
@@ -88,10 +92,12 @@ class FormFieldControl(ConstrainedControl):
             right=right,
             bottom=bottom,
             expand=expand,
+            col=col,
             opacity=opacity,
             rotate=rotate,
             scale=scale,
             offset=offset,
+            aspect_ratio=aspect_ratio,
             animate_opacity=animate_opacity,
             animate_size=animate_size,
             animate_position=animate_position,
@@ -105,17 +111,8 @@ class FormFieldControl(ConstrainedControl):
             data=data,
         )
 
-        self.__prefix: Optional[Control] = None
-        self.__suffix: Optional[Control] = None
-        self.__label_style: Optional[TextStyle] = None
-        self.__hint_style: Optional[TextStyle] = None
-        self.__helper_style: Optional[TextStyle] = None
-        self.__counter_style: Optional[TextStyle] = None
-        self.__error_style: Optional[TextStyle] = None
-        self.__prefix_style: Optional[TextStyle] = None
-        self.__suffix_style: Optional[TextStyle] = None
-
         self.text_size = text_size
+        self.text_style = text_style
         self.label = label
         self.label_style = label_style
         self.icon = icon
@@ -152,6 +149,7 @@ class FormFieldControl(ConstrainedControl):
         super()._before_build_command()
         self._set_attr_json("borderRadius", self.__border_radius)
         self._set_attr_json("contentPadding", self.__content_padding)
+        self._set_attr_json("textStyle", self.__text_style)
         self._set_attr_json("labelStyle", self.__label_style)
         self._set_attr_json("hintStyle", self.__hint_style)
         self._set_attr_json("helperStyle", self.__helper_style)
@@ -180,6 +178,16 @@ class FormFieldControl(ConstrainedControl):
     def text_size(self, value: OptionalNumber):
         self._set_attr("textSize", value)
 
+    # text_style
+    @property
+    def text_style(self):
+        return self.__text_style
+
+    @text_style.setter
+    @beartype
+    def text_style(self, value: Optional[TextStyle]):
+        self.__text_style = value
+
     # label
     @property
     def label(self):
