@@ -10,6 +10,7 @@ from flet.types import (
     AnimationValue,
     OffsetValue,
     PaddingValue,
+    ResponsiveNumber,
     RotateValue,
     ScaleValue,
 )
@@ -147,10 +148,12 @@ class NavigationRail(ConstrainedControl):
         right: OptionalNumber = None,
         bottom: OptionalNumber = None,
         expand: Union[None, bool, int] = None,
+        col: Optional[ResponsiveNumber] = None,
         opacity: OptionalNumber = None,
         rotate: RotateValue = None,
         scale: ScaleValue = None,
         offset: OffsetValue = None,
+        aspect_ratio: OptionalNumber = None,
         animate_opacity: AnimationValue = None,
         animate_size: AnimationValue = None,
         animate_position: AnimationValue = None,
@@ -186,10 +189,12 @@ class NavigationRail(ConstrainedControl):
             right=right,
             bottom=bottom,
             expand=expand,
+            col=col,
             opacity=opacity,
             rotate=rotate,
             scale=scale,
             offset=offset,
+            aspect_ratio=aspect_ratio,
             animate_opacity=animate_opacity,
             animate_size=animate_size,
             animate_position=animate_position,
