@@ -12,6 +12,7 @@ from flet.types import (
     BorderRadiusValue,
     OffsetValue,
     PaddingValue,
+    ResponsiveNumber,
     RotateValue,
     ScaleValue,
 )
@@ -46,10 +47,12 @@ class TextField(FormFieldControl):
         width: OptionalNumber = None,
         height: OptionalNumber = None,
         expand: Union[None, bool, int] = None,
+        col: Optional[ResponsiveNumber] = None,
         opacity: OptionalNumber = None,
         rotate: RotateValue = None,
         scale: ScaleValue = None,
         offset: OffsetValue = None,
+        aspect_ratio: OptionalNumber = None,
         animate_opacity: AnimationValue = None,
         animate_size: AnimationValue = None,
         animate_position: AnimationValue = None,
@@ -65,6 +68,7 @@ class TextField(FormFieldControl):
         # FormField specific
         #
         text_size: OptionalNumber = None,
+        text_style: Optional[TextStyle] = None,
         label: Optional[str] = None,
         label_style: Optional[TextStyle] = None,
         icon: Optional[str] = None,
@@ -128,10 +132,12 @@ class TextField(FormFieldControl):
             width=width,
             height=height,
             expand=expand,
+            col=col,
             opacity=opacity,
             rotate=rotate,
             scale=scale,
             offset=offset,
+            aspect_ratio=aspect_ratio,
             animate_opacity=animate_opacity,
             animate_size=animate_size,
             animate_position=animate_position,
@@ -147,6 +153,7 @@ class TextField(FormFieldControl):
             # FormField
             #
             text_size=text_size,
+            text_style=text_style,
             label=label,
             label_style=label_style,
             icon=icon,
@@ -180,6 +187,7 @@ class TextField(FormFieldControl):
             suffix_style=suffix_style,
         )
         self.value = value
+        self.text_style = text_style
         self.keyboard_type = keyboard_type
         self.text_align = text_align
         self.multiline = multiline
